pub struct HandlingError { /* private fields */ }Trait Implementations
Sourceimpl Clone for HandlingError
impl Clone for HandlingError
Sourcefn clone(&self) -> HandlingError
fn clone(&self) -> HandlingError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HandlingError
impl Debug for HandlingError
Sourceimpl Decode for HandlingError
impl Decode for HandlingError
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for HandlingError
impl Encode for HandlingError
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl From<Error> for HandlingError
impl From<Error> for HandlingError
Sourceimpl PartialEq for HandlingError
impl PartialEq for HandlingError
Sourcefn eq(&self, other: &HandlingError) -> bool
fn eq(&self, other: &HandlingError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeInfo for HandlingError
impl TypeInfo for HandlingError
impl DecodeWithMemTracking for HandlingError
impl EncodeLike for HandlingError
impl Eq for HandlingError
impl StructuralPartialEq for HandlingError