pub struct WeightFeeHandler<AccountId, C, W, T, const POLICY: bool>(/* private fields */);Expand description
A weight-based fee handler implementation that calculates and charges fees based on message processing weight.
This implementation computes the weight consumed by a batch of messages, converts this weight
into a fee, and charges the fee to the message originator’s account. The behavior is
configurable through a ChargePolicy.
Type Parameters
AccountId- The account identifier type used to identify fee payers.C- TheCurrencytrait implementation for handling balances.W- A type implementingWeightToFeeto convert computationalWeightinto aBalance.T- AGet<AccountId>implementation that returns the Treasury’s account ID.Policy- A type implementingChargePolicyto determine if fees should be charged.
Examples
This handler is typically configured in a runtime to establish a weight-based fee model.
ⓘ
// In the runtime configuration
use pallet_ismp::fee_handler::{self, WeightToFee};
use frame_support::weights::WeightToFee as SubstrateWeightToFee;
// An adapter to use the runtime's default WeightToFee implementation
pub struct IsmpWeightToFee;
impl WeightToFee for IsmpWeightToFee {
type Balance = Balance;
fn convert(weight: Weight) -> Self::Balance {
<Runtime as pallet_transaction_payment::Config>::WeightToFee::weight_to_fee(&weight)
}
}
// Define the fee handler type
type FeeHandler = fee_handler::WeightFeeHandler<
AccountId,
Balances,
IsmpWeightToFee,
TreasuryPalletId.
true
>;Trait Implementations
Sourceimpl<AccountId, C, W, T, const POLICY: bool> FeeHandler for WeightFeeHandler<AccountId, C, W, T, POLICY>where
AccountId: Member + MaybeDisplay + Decode + Encode,
C: Currency<AccountId>,
W: WeightToFee<Balance = <C as Currency<AccountId>>::Balance>,
T: Get<PalletId>,
impl<AccountId, C, W, T, const POLICY: bool> FeeHandler for WeightFeeHandler<AccountId, C, W, T, POLICY>where
AccountId: Member + MaybeDisplay + Decode + Encode,
C: Currency<AccountId>,
W: WeightToFee<Balance = <C as Currency<AccountId>>::Balance>,
T: Get<PalletId>,
Sourcefn on_executed(
messages: Vec<MessageWithWeight>,
_events: Vec<Event>,
) -> DispatchResultWithPostInfo
fn on_executed( messages: Vec<MessageWithWeight>, _events: Vec<Event>, ) -> DispatchResultWithPostInfo
Process a batch of successfully executed messages and calculate appropriate fees. Read more