pub type StateMachineUpdateTime<T: Config> = StorageMap<_GeneratedPrefixForStorageStateMachineUpdateTime<T>, Twox64Concat, StateMachineHeight, u64, OptionQuery>;Expand description
Holds the timestamp at which a state machine height was updated. Used in ensuring that the configured challenge period elapses.
Storage type is StorageMap with key type StateMachineHeight and value type u64.
Aliased Type
pub struct StateMachineUpdateTime<T: Config>(/* private fields */);